# Table of Contents

- [reference-catalog-fact-sheet-naming-conventions](<./reference-catalog-fact-sheet-naming-conventions.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Reference Catalog: Fact Sheet Naming Conventions](<./Reference-Catalog-Fact-Sheet-Naming-Conventions.md>)
  - [Overview](<./Reference-Catalog-Fact-Sheet-Naming-Conventions/Overview.md>)
  - [Applications](<./Reference-Catalog-Fact-Sheet-Naming-Conventions/Applications.md>)
  - [IT Components](<./Reference-Catalog-Fact-Sheet-Naming-Conventions/IT-Components.md>)
  - [SaaS Hosting IT Components](<./Reference-Catalog-Fact-Sheet-Naming-Conventions/SaaS-Hosting-IT-Components.md>)
  - [Was this page helpful?](<./Reference-Catalog-Fact-Sheet-Naming-Conventions/Was-this-page-helpful.md>)
